/***********************************************
 * Licensed Materials - Property of IBM
 * 
 * 5724-R31, 5655-S30
 * 
 * (C) Copyright IBM Corp. 2010 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 ***********************************************
 */

package com.ibm.websphere.icp.banking.nao.entity;

import static javax.persistence.GenerationType.IDENTITY;

import java.io.Serializable;
import java.sql.Date;
import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.JoinTable;
import javax.persistence.ManyToMany;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import static javax.persistence.FetchType.EAGER;
import static javax.persistence.CascadeType.ALL;

@Entity
@Table(schema = "BCP_NAO")
@NamedQueries( {
		@NamedQuery(name = "findArrangementById", query = "SELECT a FROM Arrangement a WHERE a.arrangementId = :arrangementId"),
		@NamedQuery(name = "findArrangementByApplicationNumber", query = "SELECT a FROM Arrangement a WHERE a.applicationnumber = :applicationnumber") })
public class Arrangement extends BankingBaseObject implements Serializable {
	@Id
	@Column(name = "ARRANGEMENT_ID")
	@GeneratedValue(strategy = IDENTITY)
	private int arrangementId;

	private String description;

	private Date enddate;

	private String initiation;

	private String initiationnature;

	private String iscompliant;

	private String lifecyclephaseinitiation;

	private String lifecyclestatus;

	private String name;

	private Date startdate;

	private Date approvaldate;

	private Date amlmonitoringdate;

	private String applicationnumber;

	private String accountnumber;

	private String accounttype;

	private String product;

	private String card;

	private String internetbanking;

	private String ivr;

	private String checkbook;

	private int checkquantity;

	private String operatinginstruction;

	private String approvedby;

	private Date depositdate;

	@ManyToOne(cascade=ALL)
	@JoinColumn(name = "CUSTOMER_ID")
	private Customer customerId;

	@OneToMany(mappedBy = "arrangementId", fetch = FetchType.EAGER, cascade={CascadeType.ALL})
	private Set<ArrangementDocs> arrangementDocsCollection;

	@OneToMany(mappedBy = "arrangementId", fetch = FetchType.EAGER, cascade={CascadeType.ALL})
	private Set<AccountStmnt> accountStmntCollection;

	@OneToMany(mappedBy = "arrangementId", fetch = FetchType.EAGER, cascade={CascadeType.ALL})
	private Set<Term> termCollection;

	@ManyToMany(fetch=EAGER, cascade = {CascadeType.ALL})
	@JoinTable(name = "CUSTOMER_ARRANGEMENT", schema = "BCP_NAO", 
			joinColumns = @JoinColumn(name = "ARRANGEMENT_ID"), 
			inverseJoinColumns = @JoinColumn(name = "CUSTOMER_ID"))
	private Set<Customer> customerCollection;

	@ManyToMany(fetch=EAGER, cascade = {CascadeType.ALL})
	@JoinTable(schema = "BCP_NAO", 
			joinColumns = @JoinColumn(name = "ARRANGEMENT_ID1"), 
			inverseJoinColumns = @JoinColumn(name = "ARRANGEMENT_ID"))
	private Set<Arrangement> arrangementCollection;

	@ManyToMany(mappedBy = "arrangementCollection", fetch=EAGER, cascade = {CascadeType.ALL})
	private Set<Arrangement> arrangementCollection2;

	private static final long serialVersionUID = 1L;

	public Arrangement() {
		super();
	}

	public int getArrangementId() {
		return this.arrangementId;
	}

	public void setArrangementId(int arrangementId) {
		this.arrangementId = arrangementId;
	}

	public String getDescription() {
		return this.description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public Date getEnddate() {
		return this.enddate;
	}

	public void setEnddate(Date enddate) {
		this.enddate = enddate;
	}

	public String getInitiation() {
		return this.initiation;
	}

	public void setInitiation(String initiation) {
		this.initiation = initiation;
	}

	public String getInitiationnature() {
		return this.initiationnature;
	}

	public void setInitiationnature(String initiationnature) {
		this.initiationnature = initiationnature;
	}

	public String getIscompliant() {
		return this.iscompliant;
	}

	public void setIscompliant(String iscompliant) {
		this.iscompliant = iscompliant;
	}

	public String getLifecyclephaseinitiation() {
		return this.lifecyclephaseinitiation;
	}

	public void setLifecyclephaseinitiation(String lifecyclephaseinitiation) {
		this.lifecyclephaseinitiation = lifecyclephaseinitiation;
	}

	public String getLifecyclestatus() {
		return this.lifecyclestatus;
	}

	public void setLifecyclestatus(String lifecyclestatus) {
		this.lifecyclestatus = lifecyclestatus;
	}

	public String getName() {
		return this.name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public Date getStartdate() {
		return this.startdate;
	}

	public void setStartdate(Date startdate) {
		this.startdate = startdate;
	}

	public Date getApprovaldate() {
		return this.approvaldate;
	}

	public void setApprovaldate(Date approvaldate) {
		this.approvaldate = approvaldate;
	}

	public Date getAmlmonitoringdate() {
		return this.amlmonitoringdate;
	}

	public void setAmlmonitoringdate(Date amlmonitoringdate) {
		this.amlmonitoringdate = amlmonitoringdate;
	}

	public String getApplicationnumber() {
		return this.applicationnumber;
	}

	public void setApplicationnumber(String applicationnumber) {
		this.applicationnumber = applicationnumber;
	}

	public String getAccountnumber() {
		return this.accountnumber;
	}

	public void setAccountnumber(String accountnumber) {
		this.accountnumber = accountnumber;
	}

	public String getAccounttype() {
		return this.accounttype;
	}

	public void setAccounttype(String accounttype) {
		this.accounttype = accounttype;
	}

	public String getProduct() {
		return this.product;
	}

	public void setProduct(String product) {
		this.product = product;
	}

	public String getCard() {
		return this.card;
	}

	public void setCard(String card) {
		this.card = card;
	}

	public String getInternetbanking() {
		return this.internetbanking;
	}

	public void setInternetbanking(String internetbanking) {
		this.internetbanking = internetbanking;
	}

	public String getIvr() {
		return this.ivr;
	}

	public void setIvr(String ivr) {
		this.ivr = ivr;
	}

	public String getCheckbook() {
		return this.checkbook;
	}

	public void setCheckbook(String checkbook) {
		this.checkbook = checkbook;
	}

	public int getCheckquantity() {
		return this.checkquantity;
	}

	public void setCheckquantity(int checkquantity) {
		this.checkquantity = checkquantity;
	}

	public String getOperatinginstruction() {
		return this.operatinginstruction;
	}

	public void setOperatinginstruction(String operatinginstruction) {
		this.operatinginstruction = operatinginstruction;
	}

	public String getApprovedby() {
		return this.approvedby;
	}

	public void setApprovedby(String approvedby) {
		this.approvedby = approvedby;
	}

	public Date getDepositdate() {
		return this.depositdate;
	}

	public void setDepositdate(Date depositdate) {
		this.depositdate = depositdate;
	}

	public Customer getCustomerId() {
		return this.customerId;
	}

	public void setCustomerId(Customer customerId) {
		this.customerId = customerId;
	}

	public Set<ArrangementDocs> getArrangementDocsCollection() {
		return this.arrangementDocsCollection;
	}

	public void setArrangementDocsCollection(
			Set<ArrangementDocs> arrangementDocsCollection) {
		this.arrangementDocsCollection = arrangementDocsCollection;
	}

	public Set<AccountStmnt> getAccountStmntCollection() {
		return this.accountStmntCollection;
	}

	public void setAccountStmntCollection(
			Set<AccountStmnt> accountStmntCollection) {
		this.accountStmntCollection = accountStmntCollection;
	}

	public Set<Term> getTermCollection() {
		return this.termCollection;
	}

	public void setTermCollection(Set<Term> termCollection) {
		this.termCollection = termCollection;
	}

	public Set<Customer> getCustomerCollection() {
		return this.customerCollection;
	}

	public void setCustomerCollection(Set<Customer> customerCollection) {
		this.customerCollection = customerCollection;
	}

	public Set<Arrangement> getArrangementCollection() {
		return this.arrangementCollection;
	}

	public void setArrangementCollection(Set<Arrangement> arrangementCollection) {
		this.arrangementCollection = arrangementCollection;
	}

	public Set<Arrangement> getArrangementCollection2() {
		return this.arrangementCollection2;
	}

	public void setArrangementCollection2(
			Set<Arrangement> arrangementCollection2) {
		this.arrangementCollection2 = arrangementCollection2;
	}

}
