/***********************************************
 * Licensed Materials - Property of IBM
 * 
 * 5724-R31, 5655-S30
 * 
 * (C) Copyright IBM Corp. 2010 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 ***********************************************
 */

package com.ibm.websphere.icp.banking.nao.entity;

import static javax.persistence.GenerationType.IDENTITY;

import java.io.Serializable;
import java.sql.Date;
import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToMany;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import static javax.persistence.FetchType.EAGER;
import static javax.persistence.CascadeType.ALL;

@Entity
@Table(schema = "BCP_NAO")
@NamedQueries( {
		@NamedQuery(name = "findCustomerById", query = "SELECT c FROM Customer c WHERE c.customerId = :customerId"),
		@NamedQuery(name = "findCustomerByLoginid", query = "SELECT c FROM Customer c WHERE c.loginid = :loginid") })
public class Customer extends BankingBaseObject implements Serializable {
	@Id
	@Column(name = "CUSTOMER_ID")
	@GeneratedValue(strategy = IDENTITY)
	private int customerId;

	private String creditworthiness;

	private long importancelevel;

	private String lifecyclestatus;

	private Date enddate;

	private Date startdate;

	private String endreason;

	private String loginid;

	private Date dateofbirth;

	private String gender;

	private String maritalstatus;

	private String ssn;

	private String age;

	private String citizenshipcountry;

	private String residencestatusofus;

	private String relationshipmanager;

	private String relationshipcode;

	private String customerstatus;

	private String newcustomer;

	private String firstname;

	private String initials;

	private String lastname;

	private String middlenames;

	private String prefixtitle;

	private String shortfirstname;

	private String suffixtitle;

	private String description;

	private String fullname;

	private String usage;

	private String aliastype;

	@ManyToOne(cascade=ALL)
	@JoinColumn(name = "POSTAL_ADDRESS_ID")
	private PostalAddress postalAddressId;

	@OneToMany(mappedBy = "customerId", fetch = EAGER, cascade={CascadeType.ALL})
	private Set<ContactDetails> contactDetailsCollection;

	@OneToMany(mappedBy = "customerId", fetch = EAGER, cascade={CascadeType.ALL})
	private Set<Arrangement> arrangementCollection;

	@OneToMany(mappedBy = "customerId", fetch = EAGER, cascade={CascadeType.ALL})
	private Set<EmploymentDetails> employmentDetailsCollection;

	@OneToMany(mappedBy = "customerId", fetch = EAGER, cascade={CascadeType.ALL})
	private Set<ResidenceDetails> residenceDetailsCollection;

	@ManyToMany(mappedBy = "customerCollection", fetch = EAGER, cascade={CascadeType.ALL})
	private Set<Arrangement> arrangementCollection2;

	private static final long serialVersionUID = 1L;

	public Customer() {
		super();
	}

	public int getCustomerId() {
		return this.customerId;
	}

	public void setCustomerId(int customerId) {
		this.customerId = customerId;
	}

	public String getCreditworthiness() {
		return this.creditworthiness;
	}

	public void setCreditworthiness(String creditworthiness) {
		this.creditworthiness = creditworthiness;
	}

	public long getImportancelevel() {
		return this.importancelevel;
	}

	public void setImportancelevel(long importancelevel) {
		this.importancelevel = importancelevel;
	}

	public String getLifecyclestatus() {
		return this.lifecyclestatus;
	}

	public void setLifecyclestatus(String lifecyclestatus) {
		this.lifecyclestatus = lifecyclestatus;
	}

	public Date getEnddate() {
		return this.enddate;
	}

	public void setEnddate(Date enddate) {
		this.enddate = enddate;
	}

	public Date getStartdate() {
		return this.startdate;
	}

	public void setStartdate(Date startdate) {
		this.startdate = startdate;
	}

	public String getEndreason() {
		return this.endreason;
	}

	public void setEndreason(String endreason) {
		this.endreason = endreason;
	}

	public String getLoginid() {
		return this.loginid;
	}

	public void setLoginid(String loginid) {
		this.loginid = loginid;
	}

	public Date getDateofbirth() {
		return this.dateofbirth;
	}

	public void setDateofbirth(Date dateofbirth) {
		this.dateofbirth = dateofbirth;
	}

	public String getGender() {
		return this.gender;
	}

	public void setGender(String gender) {
		this.gender = gender;
	}

	public String getMaritalstatus() {
		return this.maritalstatus;
	}

	public void setMaritalstatus(String maritalstatus) {
		this.maritalstatus = maritalstatus;
	}

	public String getSsn() {
		return this.ssn;
	}

	public void setSsn(String ssn) {
		this.ssn = ssn;
	}

	public String getAge() {
		return this.age;
	}

	public void setAge(String age) {
		this.age = age;
	}

	public String getCitizenshipcountry() {
		return this.citizenshipcountry;
	}

	public void setCitizenshipcountry(String citizenshipcountry) {
		this.citizenshipcountry = citizenshipcountry;
	}

	public String getResidencestatusofus() {
		return this.residencestatusofus;
	}

	public void setResidencestatusofus(String residencestatusofus) {
		this.residencestatusofus = residencestatusofus;
	}

	public String getRelationshipmanager() {
		return this.relationshipmanager;
	}

	public void setRelationshipmanager(String relationshipmanager) {
		this.relationshipmanager = relationshipmanager;
	}

	public String getRelationshipcode() {
		return this.relationshipcode;
	}

	public void setRelationshipcode(String relationshipcode) {
		this.relationshipcode = relationshipcode;
	}

	public String getCustomerstatus() {
		return this.customerstatus;
	}

	public void setCustomerstatus(String customerstatus) {
		this.customerstatus = customerstatus;
	}

	public String getNewcustomer() {
		return this.newcustomer;
	}

	public void setNewcustomer(String newcustomer) {
		this.newcustomer = newcustomer;
	}

	public String getFirstname() {
		return this.firstname;
	}

	public void setFirstname(String firstname) {
		this.firstname = firstname;
	}

	public String getInitials() {
		return this.initials;
	}

	public void setInitials(String initials) {
		this.initials = initials;
	}

	public String getLastname() {
		return this.lastname;
	}

	public void setLastname(String lastname) {
		this.lastname = lastname;
	}

	public String getMiddlenames() {
		return this.middlenames;
	}

	public void setMiddlenames(String middlenames) {
		this.middlenames = middlenames;
	}

	public String getPrefixtitle() {
		return this.prefixtitle;
	}

	public void setPrefixtitle(String prefixtitle) {
		this.prefixtitle = prefixtitle;
	}

	public String getShortfirstname() {
		return this.shortfirstname;
	}

	public void setShortfirstname(String shortfirstname) {
		this.shortfirstname = shortfirstname;
	}

	public String getSuffixtitle() {
		return this.suffixtitle;
	}

	public void setSuffixtitle(String suffixtitle) {
		this.suffixtitle = suffixtitle;
	}

	public String getDescription() {
		return this.description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public String getFullname() {
		return this.fullname;
	}

	public void setFullname(String fullname) {
		this.fullname = fullname;
	}

	public String getUsage() {
		return this.usage;
	}

	public void setUsage(String usage) {
		this.usage = usage;
	}

	public String getAliastype() {
		return this.aliastype;
	}

	public void setAliastype(String aliastype) {
		this.aliastype = aliastype;
	}

	public PostalAddress getPostalAddressId() {
		return this.postalAddressId;
	}

	public void setPostalAddressId(PostalAddress postalAddressId) {
		this.postalAddressId = postalAddressId;
	}

	public Set<ContactDetails> getContactDetailsCollection() {
		return this.contactDetailsCollection;
	}

	public void setContactDetailsCollection(
			Set<ContactDetails> contactDetailsCollection) {
		this.contactDetailsCollection = contactDetailsCollection;
	}

	public Set<Arrangement> getArrangementCollection() {
		return this.arrangementCollection;
	}

	public void setArrangementCollection(Set<Arrangement> arrangementCollection) {
		this.arrangementCollection = arrangementCollection;
	}

	public Set<EmploymentDetails> getEmploymentDetailsCollection() {
		return this.employmentDetailsCollection;
	}

	public void setEmploymentDetailsCollection(
			Set<EmploymentDetails> employmentDetailsCollection) {
		this.employmentDetailsCollection = employmentDetailsCollection;
	}

	public Set<ResidenceDetails> getResidenceDetailsCollection() {
		return this.residenceDetailsCollection;
	}

	public void setResidenceDetailsCollection(
			Set<ResidenceDetails> residenceDetailsCollection) {
		this.residenceDetailsCollection = residenceDetailsCollection;
	}

	public Set<Arrangement> getArrangementCollection2() {
		return this.arrangementCollection2;
	}

	public void setArrangementCollection2(
			Set<Arrangement> arrangementCollection2) {
		this.arrangementCollection2 = arrangementCollection2;
	}

}
